==> nextcloud-app-calendar-1%3A6.0.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/ka_GE.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s მომხმარებელმა გამოაქვეყნა კალენდარი »%s«",
    "Hello," : "გამარჯობა,",
    "We wanted to inform you that %s has published the calendar »%s«." : "გვსურს შეგატყობინოთ, რომ %s მომხმარებელმა გამოაქყვენა კალენდარი »%s«.",
    "Open »%s«" : "გახნსნა »%s«",
    "Cheers!" : "წარმატებები!",
    "Calendar" : "კალენდარი",
    "Confirm" : "დადასტურება",
    "Description:" : "აღწერა:",
    "Where:" : "სად:",
    "Location:" : "ადგილმდებარეობა:",
    "Today" : "დღეს",
    "Day" : "დღე",
    "Week" : "კვირა",
    "Month" : "თვე",
    "List" : "ჩამონათვალი",
    "Preview" : "წინასწარი ჩვენება",
    "Copy link" : "ბმულის კოპირება",
    "Edit" : "შეცვლა",
    "Delete" : "წაშლა",
    "New calendar" : "ახალი კალენდარი",
    "Export" : "ექსპორტი",
    "Name" : "სახელი",
    "Deleted" : "გაუქმდა",
    "Restore" : "აღდგენა",
    "Delete permanently" : "სამუდამოდ წაშლა",
    "Deck" : "დასტა",
    "Share link" : "ბმულის გაზიარება",
    "Share with users or groups" : "გაზიარება მოხმარებლებთან ან ჯგუფებთან",
    "Save" : "შენახვა",
    "Filename" : "ფაილის სახელი",
    "Cancel" : "უარყოფა",
    "Automatic" : "ავტომატური",
    "List view" : "ჩამონათვლისებური ხედი",
    "Actions" : "მოქმედებები",
    "or" : "ან",
    "General" : "ზოგადი",
    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
    "Update" : "განახლება",
    "Location" : "ადგილმდებარეობა",
    "Description" : "აღწერილობა",
    "to" : "ვის",
    "Add" : "დამატება",
    "Monday" : "ორშაბათი",
    "Tuesday" : "სამშაბათი",
    "Wednesday" : "ოთხშაბათი",
    "Thursday" : "ხუთშაბათი",
    "Friday" : "პარასკევი",
    "Saturday" : "შაბათი",
    "Sunday" : "კვირა",
    "Your email address" : "თქვენი ელ-ფოსტის მისამართი",
    "Notification" : "შეტყობინება",
    "Email" : "ელ-ფოსტა",
    "days" : "დღე",
    "weeks" : "კვირა",
    "Choose a file to add as attachment" : "დანართად დასამატებლად აირჩიეთ ფაილი",
    "Delete file" : "გაუქმდეს ფაილი",
    "Done" : "დასრულდა",
    "Room name" : "ოთახის სახელი",
    "Unknown" : "ამოუცნობი",
    "Accept" : "მიღება",
    "Decline" : "ურაყოფა",
    "Tentative" : "საცდელი",
    "Attendees" : "დამსწრეები",
    "Repeat" : "გამეორება",
    "never" : "არასდროს",
    "after" : "შემდეგ",
    "Resources" : "რესურსები",
    "available" : "ხელმისაწვდომი",
    "Yes" : "დიახ",
    "Maybe" : "შესაძლოა",
    "None" : "არც ერთი",
    "Global" : "გლობალური",
    "Subscribe" : "გამოწერა",
    "Personal" : "პირადი",
    "Edit event" : "მოვლენის ცვლილება",
    "All day" : "მთელი დღე",
    "Close" : "დახურვა",
    "Title" : "სათაური",
    "Participants" : "მონაწილეები",
    "Submit" : "გაგზავნა",
    "Anniversary" : "დაბადების დღე",
    "Week {number} of {year}" : "კვირა {number} {year}-დან",
    "Daily" : "ყოველდღიური",
    "Weekly" : "ყოველკვირეული",
    "Other" : "სხვა",
    "When shared show full event" : "როდესაც გაზიარებულია გამოჩნდეს სრული მოვლენა",
    "When shared show only busy" : "როდესაც გაზიარებულია გამოჩნდეს მხოლოდ დაკავებული",
    "When shared hide this event" : "როდესაც გაზიარებულია არ გამოჩნდეს ეს მოვლენა",
    "Status" : "სტატუსი",
    "Confirmed" : "დადასტურებლია",
    "Categories" : "კატეგორიები",
    "Hidden" : "უჩინარი",
    "can edit" : "შეგიძლია შეცვლა",
    "Show week numbers" : "კვირის ნომრების ჩვენება"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-app-calendar-1%3A6.1.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/ka_GE.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s მომხმარებელმა გამოაქვეყნა კალენდარი »%s«",
    "Hello," : "გამარჯობა,",
    "We wanted to inform you that %s has published the calendar »%s«." : "გვსურს შეგატყობინოთ, რომ %s მომხმარებელმა გამოაქყვენა კალენდარი »%s«.",
    "Open »%s«" : "გახნსნა »%s«",
    "Cheers!" : "წარმატებები!",
    "Calendar" : "კალენდარი",
    "Confirm" : "დადასტურება",
    "Description:" : "აღწერა:",
    "Where:" : "სად:",
    "Location:" : "ადგილმდებარეობა:",
    "Today" : "დღეს",
    "Day" : "დღე",
    "Week" : "კვირა",
    "Month" : "თვე",
    "List" : "ჩამონათვალი",
    "Preview" : "წინასწარი ჩვენება",
    "Copy link" : "ბმულის კოპირება",
    "Edit" : "შეცვლა",
    "Delete" : "წაშლა",
    "New calendar" : "ახალი კალენდარი",
    "Export" : "ექსპორტი",
    "Name" : "სახელი",
    "Deleted" : "გაუქმდა",
    "Restore" : "აღდგენა",
    "Delete permanently" : "სამუდამოდ წაშლა",
    "Deck" : "დასტა",
    "Share link" : "ბმულის გაზიარება",
    "Share with users or groups" : "გაზიარება მოხმარებლებთან ან ჯგუფებთან",
    "Save" : "შენახვა",
    "Filename" : "ფაილის სახელი",
    "Cancel" : "უარყოფა",
    "Automatic" : "ავტომატური",
    "List view" : "ჩამონათვლისებური ხედი",
    "Actions" : "მოქმედებები",
    "or" : "ან",
    "General" : "ზოგადი",
    "Update" : "განახლება",
    "Location" : "ადგილმდებარეობა",
    "Description" : "აღწერილობა",
    "to" : "ვის",
    "Add" : "დამატება",
    "Monday" : "ორშაბათი",
    "Tuesday" : "სამშაბათი",
    "Wednesday" : "ოთხშაბათი",
    "Thursday" : "ხუთშაბათი",
    "Friday" : "პარასკევი",
    "Saturday" : "შაბათი",
    "Sunday" : "კვირა",
    "Your email address" : "თქვენი ელ-ფოსტის მისამართი",
    "Notification" : "შეტყობინება",
    "Email" : "ელ-ფოსტა",
    "days" : "დღე",
    "weeks" : "კვირა",
    "Choose a file to add as attachment" : "დანართად დასამატებლად აირჩიეთ ფაილი",
    "Delete file" : "გაუქმდეს ფაილი",
    "Done" : "დასრულდა",
    "Room name" : "ოთახის სახელი",
    "Unknown" : "ამოუცნობი",
    "Accept" : "მიღება",
    "Decline" : "ურაყოფა",
    "Tentative" : "საცდელი",
    "Attendees" : "დამსწრეები",
    "Repeat" : "გამეორება",
    "never" : "არასდროს",
    "after" : "შემდეგ",
    "Resources" : "რესურსები",
    "available" : "ხელმისაწვდომი",
    "Yes" : "დიახ",
    "Maybe" : "შესაძლოა",
    "None" : "არც ერთი",
    "Global" : "გლობალური",
    "Subscribe" : "გამოწერა",
    "Personal" : "პირადი",
    "Edit event" : "მოვლენის ცვლილება",
    "All day" : "მთელი დღე",
    "Close" : "დახურვა",
    "Title" : "სათაური",
    "Participants" : "მონაწილეები",
    "Submit" : "გაგზავნა",
    "Anniversary" : "დაბადების დღე",
    "Week {number} of {year}" : "კვირა {number} {year}-დან",
    "Daily" : "ყოველდღიური",
    "Weekly" : "ყოველკვირეული",
    "Other" : "სხვა",
    "When shared show full event" : "როდესაც გაზიარებულია გამოჩნდეს სრული მოვლენა",
    "When shared show only busy" : "როდესაც გაზიარებულია გამოჩნდეს მხოლოდ დაკავებული",
    "When shared hide this event" : "როდესაც გაზიარებულია არ გამოჩნდეს ეს მოვლენა",
    "Status" : "სტატუსი",
    "Confirmed" : "დადასტურებლია",
    "Categories" : "კატეგორიები",
    "Hidden" : "უჩინარი",
    "can edit" : "შეგიძლია შეცვლა",
    "Show week numbers" : "კვირის ნომრების ჩვენება",
    "Keyboard shortcuts" : "კლავიატურის კომბინაციები"
},
"nplurals=2; plural=(n!=1);");
